@@ -194,7 +194,7 @@ fn target_env_var_os(name: &str, target: &str) -> Option<OsString> {
     env::var_os(format!("{}_{}", name, target))
         .or_else(|| env::var_os(format!("{}_{}", name, target_underscores)))
         .or_else(|| env::var_os(format!("TARGET_{}", name)))
-        .or_else(|| env::var_os(name.to_string()))
+        .or_else(|| env::var_os(name))
 }
 
 fn rerun_if_env_changed(name: &str, target: &str) {
@@ -271,7 +271,7 @@ fn find_and_output_lib_dir(link_paths: &[PathBuf], target: &str, explicit_static
 
             for &lib_dir in &[
                 link_path,
-                &link_path.join(&target),
+                &link_path.join(target),
                 &link_path.join(&triplet),
             ] {
                 let lib_path = lib_dir.join(&file_name);
@@ -296,7 +296,8 @@ fn generate_bindings(out_dir: &Path, include_path: &Path) {
         .derive_copy(true)
         .derive_eq(true)
         .derive_ord(true)
-        .impl_debug(true);
+        .impl_debug(true)
+        .clang_args(&["-I", path_to_str(include_path)]);
 
     // Do not expose deprecated functions.
     for &blacklisted_function in &[
